function s_sat = moist_ape_sat_entropy(T, p, wt, thermo_type);

% calculate saturation entropy using equation 15 of Lorenz 1969
% -can be used with ice as doesn't involve heat capacity of ice or liquid water;
%  these are implied by L; see Wang and Randall 1994
% -typo pointed out in Randall 1992 is corrected
  
 error(nargchk(4, 4, nargin))     

 switch lower(thermo_type)
  case 'full'
   cpw            = PARS('cp_v'); % specific heat capacity of water vapor
  case 'simple'
   % assume have the same heat capacity for water vapor and dry air in simple case
   cpw            = PARS('cp');
  otherwise
   error(['Unknown type, ', thermo_type, 'of thermodynamic formulation.'])
 end

 R              = PARS('gas_constant');
 Rw             = PARS('gas_constant_v');
 cp             = PARS('cp');
 eps            = R/Rw;

 [es, L] = moist_ape_es(T, thermo_type);
 w  = eps*es./(p-es);

 s_sat = ((cp+wt*cpw).*log(T)-...
         R.*log(p-es)-wt.*Rw.*log(es)-...
         (wt-w).*L./T)./(1+wt); % equation 15 Lorenz with Randall 92 correction

